Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4)

Unified Diff: chrome/browser/chromeos/chrome_browser_main_chromeos.cc

Issue 2420843002: Do not watch for low disk events in guest mode. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/chrome_browser_main_chromeos.cc
diff --git a/chrome/browser/chromeos/chrome_browser_main_chromeos.cc b/chrome/browser/chromeos/chrome_browser_main_chromeos.cc
index d2acdd20c68609a5555b6b83898abe758ecb170d..f78c69e29a638dd46d72e5b5c5e6642fbbf79a62 100644
--- a/chrome/browser/chromeos/chrome_browser_main_chromeos.cc
+++ b/chrome/browser/chromeos/chrome_browser_main_chromeos.cc
@@ -688,8 +688,10 @@ void ChromeBrowserMainPartsChromeos::PostProfileInit() {
// available.
idle_action_warning_observer_.reset(new IdleActionWarningObserver());
- // Start watching for low disk space events to notify the user.
- low_disk_notification_.reset(new LowDiskNotification());
+ // Start watching for low disk space events to notify the user if it is not a
+ // guest profile.
+ if (!user_manager::UserManager::Get()->IsLoggedInAsGuest())
+ low_disk_notification_.reset(new LowDiskNotification());
// Authenticate the user for PIN quick unlock.
PinStorage* pin_storage = PinStorageFactory::GetForProfile(profile());
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698